@@ -3,16 +3,17 @@ from collections.abc import Mapping
 from dataclasses import asdict, is_dataclass
 from contextlib import ExitStack
 from csv import DictWriter, DictReader
+from functools import wraps
 from pathlib import Path
 from typing import Collection, Any, TextIO, Type, Tuple, Iterator
 
-from nv.utils.collections.structures import normalize_row
-
 from ..core import Serializer
+from ..normalization import normalize_row
 from ..typing import DataTable, DataStructure, ParsedDataRow, ParsedDataStructure, ParsedDataTable
 
 
-__ALL__ = ['CSVSerializer', 'csv', ]
+__ALL__ = ['CSVSerializer', 'dump', 'write_table', 'load', 'read_table', 'read_headers', 'read_schema', 'iter_table',
+           'iter_structure']
 
 
 class CSVSerializer(Serializer):
@@ -31,9 +32,6 @@ class CSVSerializer(Serializer):
     def write_table(self, table: DataTable, fp: Path | str | TextIO, headers: Collection[str] = None,
                     default: Any = DEFAULT_EMPTY_ON_WRITE, encoding: str = None, **serializer_kwargs) -> None:
 
-        if not table:
-            raise ValueError(f"unable to write an empty table to '{fp}'")
-
         with ExitStack() as stack:
             if isinstance(fp, str | Path):
                 fp = stack.enter_context(Path(fp).open('w', encoding=self._get_encoding(fp, encoding)))
@@ -42,8 +40,6 @@ class CSVSerializer(Serializer):
 
     def append_table(self, table: DataTable, fp: Path | str | TextIO, headers: Collection[str] = None,
                      default: Any = DEFAULT_EMPTY_ON_WRITE, encoding: str = None, **serializer_kwargs) -> None:
-        if not table:
-            raise ValueError(f"unable to append an empty table to '{fp}'")
 
         with ExitStack() as stack:
             if isinstance(fp, str | Path):
@@ -54,8 +50,6 @@ class CSVSerializer(Serializer):
     def dump(self, structure: DataStructure, fp: Path | str | TextIO, schema: Mapping[Collection[str]] = None,
              pattern=DEFAULT_NAMING_PATTERN, default: Any = DEFAULT_EMPTY_ON_WRITE, encoding: str = None,
              **serializer_kwargs) -> None:
-        if not structure:
-            raise ValueError(f"unable to append an empty structure to '{fp}'")
 
         schema = schema or dict()
 
@@ -175,4 +169,13 @@ class CSVSerializer(Serializer):
 
 
 # Default implementation
-csv = CSVSerializer()
+__csv_serializer = CSVSerializer()
+
+write_table = wraps(__csv_serializer.write_table)
+dump = wraps(__csv_serializer.dump)
+load = wraps(__csv_serializer.load)
+read_table = wraps(__csv_serializer.read_table)
+read_headers = wraps(__csv_serializer.read_headers)
+read_schema = wraps(__csv_serializer.read_schema)
+iter_table = wraps(__csv_serializer.iter_table)
+iter_structure = wraps(__csv_serializer.iter_structure)
