@@ -26,12 +26,13 @@ if find_spec('xlutils'):
 else:
     xlutils = None
 
-from ..core import requires
+from ..decorators import requires
 from ..spreadsheets import SpreadsheetSerializer
 from ..typing import ParsedDataRow
 
 
-__ALL__ = ['XLSSerializer', 'xls', ]
+__ALL__ = ['XLSSerializer', 'dump', 'write_table', 'load', 'read_table', 'read_headers', 'read_schema', 'iter_table',
+           'iter_structure']
 
 
 class XLSSerializer(SpreadsheetSerializer):
@@ -168,4 +169,13 @@ class XLSSerializer(SpreadsheetSerializer):
 
 
 # Default implementation
-xls = XLSSerializer()
+__xls_serializer = XLSSerializer()
+
+write_table = wraps(__xls_serializer.write_table)
+dump = wraps(__xls_serializer.dump)
+load = wraps(__xls_serializer.load)
+read_table = wraps(__xls_serializer.read_table)
+read_headers = wraps(__xls_serializer.read_headers)
+read_schema = wraps(__xls_serializer.read_schema)
+iter_table = wraps(__xls_serializer.iter_table)
+iter_structure = wraps(__xls_serializer.iter_structure)
