@@ -18,14 +18,15 @@ else:
     Workbook = TypeVar('Workbook')
     Worksheet = TypeVar('Worksheet')
 
-from nv.utils.collections.structures import normalize_row
+from ..normalization import normalize_row
 
-from ..core import requires
+from ..decorators import requires
 from ..spreadsheets import SpreadsheetSerializer
 from ..typing import ParsedDataRow
 
 
-__ALL__ = ['XLSXSerializer', 'xlsx', ]
+__ALL__ = ['XLSXSerializer', 'dump', 'write_table', 'load', 'read_table', 'read_headers', 'read_schema', 'iter_table',
+           'iter_structure']
 
 
 class XLSXSerializer(SpreadsheetSerializer):
@@ -112,4 +113,13 @@ class XLSXSerializer(SpreadsheetSerializer):
 
 
 # Default implementation
-xlsx = XLSXSerializer()
+__xlsx_serializer = XLSXSerializer()
+
+write_table = wraps(__xlsx_serializer.write_table)
+dump = wraps(__xlsx_serializer.dump)
+load = wraps(__xlsx_serializer.load)
+read_table = wraps(__xlsx_serializer.read_table)
+read_headers = wraps(__xlsx_serializer.read_headers)
+read_schema = wraps(__xlsx_serializer.read_schema)
+iter_table = wraps(__xlsx_serializer.iter_table)
+iter_structure = wraps(__xlsx_serializer.iter_structure)
