@@ -1,6 +1,10 @@
-from typing import Dict, Any, Mapping, List, Iterable, Tuple
+import dataclasses
+from typing import Dict, Any, Mapping, List, Iterable, Tuple, ClassVar, Protocol
 
-from nv.utils.typing import DataClass
+
+class DataClass(Protocol):
+    __dataclass_fields__: ClassVar[Dict[str, 'dataclasses.Field']]
+    __dataclass_params__: ClassVar[Any]
 
 
 # Generic data structures
